@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004, 2005, 2006 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2005, 2006, 2009 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -529,10 +529,11 @@ static char * os_get_installation_path() {
 #endif
 #if DARWIN
   dima = get_path_from_dyld_image();
+  path = NULL;
 #else
   dima = NULL;
-#endif
   path = get_path_from_PATH();
+#endif
   n = 1;
   if (lpref != NULL)
     n += strlen(lpref) + strlen(PLUGINDIR "/:");
@@ -593,7 +594,6 @@ void __attribute__ ((constructor)) le_ltdl_init() {
   char * cpath;
 
 #if ENABLE_NLS
-  setlocale(LC_ALL, "");
   BINDTEXTDOMAIN(PACKAGE, LOCALEDIR);
   BINDTEXTDOMAIN("iso-639", ISOLOCALEDIR); /* used by wordextractor */
 #endif
@@ -790,20 +790,14 @@ loadLibrary (const char *name,
 	     void **libHandle,
 	     ExtractMethod * method)
 {
-#if 0
   lt_dladvise advise;
-#endif
 
   LTDL_MUTEX_LOCK
-#if 0
   lt_dladvise_init(&advise);
   lt_dladvise_ext(&advise);
   lt_dladvise_local(&advise);
-  *libHandle = lt_dlopenadvise (name, &advise);
+  *libHandle = lt_dlopenadvise (name, advise);
   lt_dladvise_destroy(&advise);
-#else
-  *libHandle = lt_dlopenext (name);
-#endif
   if (*libHandle == NULL)
     {
 #if DEBUG
@@ -1317,7 +1311,7 @@ EXTRACTOR_getKeywords (EXTRACTOR_ExtractorList * extractor,
     if (-1 == file)
       return NULL;
   
-    size = fstatbuf.st_size;
+    size = (fstatbuf.st_size > 0xFFFFFFFF) ? 0xFFFFFFFF : fstatbuf.st_size;
     if (size == 0) {
       close(file);
       return NULL;
