@@ -32,15 +32,17 @@
 #include "platform.h"
 #include "extractor.h"
 
-#include "exif.hpp"
-#include "image.hpp"
-#include "futils.hpp"
+#include "exiv2/exif.hpp"
+#include "exiv2/image.hpp"
+#include "exiv2/futils.hpp"
 
 #define WORKAROUND_905 1
 #if WORKAROUND_905
 #include <pthread.h>
 #endif
 
+#define SUPPRESS_WARNINGS 1
+
 extern "C" {
 
     static struct EXTRACTOR_Keywords * addKeyword(EXTRACTOR_KeywordType type,
@@ -189,7 +191,7 @@ extern "C" {
         // Flash bias
         // Todo: Implement this for other cameras
         newResult = addExiv2Tag(exifData,
-                                "Exif.CanonCs2.FlashBias",
+                                "Exif.CanonSi.FlashBias",
                                 EXTRACTOR_FLASH_BIAS,
                                 result);
         if (newResult == result) {
@@ -226,7 +228,7 @@ extern "C" {
                                 result);
         if (newResult == result) {
             newResult = addExiv2Tag(exifData,
-                                    "Exif.CanonCs1.ISOSpeed",
+                                    "Exif.CanonSi.ISOSpeed",
                                     EXTRACTOR_ISO_SPEED,
                                     result);
         }
@@ -258,7 +260,7 @@ extern "C" {
                                 result);
         if (newResult == result) {
             newResult = addExiv2Tag(exifData,
-                                    "Exif.CanonCs1.ExposureProgram",
+                                    "Exif.CanonCs.ExposureProgram",
                                     EXTRACTOR_EXPOSURE_MODE,
                                     result);
         }
@@ -273,7 +275,7 @@ extern "C" {
         // Macro mode
         // Todo: Implement this for other cameras
         newResult = addExiv2Tag(exifData,
-                                "Exif.CanonCs1.Macro",
+                                "Exif.CanonCs.Macro",
                                 EXTRACTOR_MACRO_MODE,
                                 result);
         if (newResult == result) {
@@ -299,7 +301,7 @@ extern "C" {
         // Image quality setting (compression)
         // Todo: Implement this for other cameras
         newResult = addExiv2Tag(exifData,
-                                "Exif.CanonCs1.Quality",
+                                "Exif.CanonCs.Quality",
                                 EXTRACTOR_IMAGE_QUALITY,
                                 result);
         if (newResult == result) {
@@ -346,7 +348,6 @@ extern "C" {
         }
         result = newResult;
 
-#if 0
 	/* this can sometimes be wrong (corrupt exiv2 data?).
 	   Either way, we should get the data directly from
 	   the specific file format parser (i.e. jpeg, tiff). */
@@ -364,12 +365,11 @@ extern "C" {
                                 strdup(os.str().c_str()),
                                 result);
         }
-#endif
         // White balance
         // Todo: Implement this for other cameras
 
         newResult = addExiv2Tag(exifData,
-                                "Exif.CanonCs2.WhiteBalance",
+                                "Exif.CanonSi.WhiteBalance",
                                 EXTRACTOR_WHITE_BALANCE,
                                 result);
         if (newResult == result) {
