@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2004, 2005, 2006 Vidyut Samanta and Christian Grothoff
+     (C) 2004, 2005, 2006, 2007 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -27,7 +27,7 @@
 
 #include "platform.h"
 #include "extractor.h"
-#include "../convert.h"
+#include "convert.h"
 
 #include <glib-object.h>
 #include <string.h>
@@ -44,11 +44,6 @@
 
 /* ******************************** main extraction code ************************ */
 
-/* using libgobject, needs init! */
-void __attribute__ ((constructor)) ole_gobject_init(void) {
- g_type_init();
-}
-
 static struct EXTRACTOR_Keywords *
 addKeyword(EXTRACTOR_KeywordList *oldhead,
 	   const char *phrase,
@@ -399,14 +394,14 @@ history_extract(GsfInput * stream,
   // there are n strings, so n/2 revisions (author & file)
   nRev = (lbuffer[2] + (lbuffer[3] << 8)) / 2;
   where = 6;
-  for (i=0; i < nRev; i++) {	
+  for (i=0; i < nRev; i++) {
     if (where >= lcbSttbSavedBy)
       break;
     length = lbuffer[where++];
     if ( (where + 2 * length + 2 >= lcbSttbSavedBy) ||
 	 (where + 2 * length + 2 <= where) )
       break;
-    author = convertToUtf8((const char*) &lbuffer[where],
+    author = EXTRACTOR_common_convert_to_utf8((const char*) &lbuffer[where],
 			   length * 2,
 			   "UTF-16BE");
     where += length * 2 + 1;
@@ -416,9 +411,9 @@ history_extract(GsfInput * stream,
       free(author);
       break;
     }
-    filename = convertToUtf8((const char*) &lbuffer[where],
+    filename = EXTRACTOR_common_convert_to_utf8((const char*) &lbuffer[where],
 			     length * 2,
-			     "UTF-16BE");	
+			     "UTF-16BE");
     where += length * 2 + 1;
     rbuf = malloc(strlen(author) + strlen(filename) + 512);
     snprintf(rbuf, 512 + strlen(author) + strlen(filename),
@@ -446,7 +441,6 @@ libextractor_ole2_extract(const char * filename,
   GsfInput * input;
   GsfInfile * infile;
   GsfInput * src;
-  GError * err = NULL;
   const char * name;
   const char * generator = NULL;
   int i;
@@ -464,7 +458,7 @@ libextractor_ole2_extract(const char * filename,
   if (input == NULL)
     return prev;
 
-  infile = gsf_infile_msole_new(input, &err);
+  infile = gsf_infile_msole_new(input, NULL);
   if (infile == NULL) {
     g_object_unref(G_OBJECT(input));
     return prev;
@@ -561,16 +555,24 @@ libextractor_ole2_extract(const char * filename,
 
   return prev;
 }
+static void nolog (const gchar *log_domain,
+		   GLogLevelFlags log_level,
+		   const gchar *message,
+		   gpointer user_data) {
+}
 
 void __attribute__ ((constructor)) ole2_ltdl_init() {
-#ifdef gsf_init
+ g_type_init();
+#ifdef HAVE_GSF_INIT
   gsf_init();
 #endif
+  /* disable logging -- thanks, Jody! */
+  g_log_set_handler ("libgsf:msole", G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING,  &nolog, NULL);
   // gsf_init_dynamic(NULL);
 }
 
 void __attribute__ ((destructor)) ole2_ltdl_fini() {
-#ifdef gsf_init
+#ifdef HAVE_GSF_INIT
   gsf_shutdown();
 #endif
   // gsf_shutdown_dynamic(NULL);
